I'm Feeling Lucky: Google's New Year Surprise
Description: Google doesn't just have a new logo today: the creative web company has also hidden a surprise on its homepage. Go to Google.com today and click "I'm Feeling Lucky" (without ent...
Keywords: mashable, google, i-m-feeling-lucky
Date: 2010-01-01 09:32:17 UTC

# Mashable

We're using cookies to improve your experience. Click Here to find out more.

## Social Media

Like Follow

# I'm Feeling Lucky: Google's New Year Surprise

150
Shares
Share
Tweet
Share
What's This?
By Pete Cashmore2010-01-01 09:32:17 UTC

Google doesn't just have a new logo today: the creative web company has also hidden a surprise on its homepage.

Go to Google.com today and click "I'm Feeling Lucky" (without entering a search term) to get an unexpected treat.

Google is increasingly drawing attention to its homepage through more and more custom logos: some argue that these are a counter to Bing.com's daily photo, which makes the rival search engine a daily visit for many. Is today's hidden gem just for fun, or a subtle reminder to visit Google.com once in awhile?

Load Comments
Powered by Livefyre

## More in Social Media

What's New
What's Rising
What's Hot

# What's New

# What's Rising

# What's Hot